@@ -8,6 +8,7 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.assertions._jsii
 import aws_cdk.aws_codebuild._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_events_targets._jsii
@@ -17,10 +18,11 @@ import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_s3._jsii
 import aws_cdk.core._jsii
 import aws_cdk.custom_resources._jsii
+import cdk_iam_floyd._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-prowler", "1.117.8", __name__[0:-6], "cdk-prowler@1.117.8.jsii.tgz"
+    "cdk-prowler", "1.118.1", __name__[0:-6], "cdk-prowler@1.118.1.jsii.tgz"
 )
 
 __all__ = [
